<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="62"/>
        <source>MX Repo Manager</source>
        <translation>MX Menedżer repozytoriów</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Wybierz repozytorium APT, którego chcesz użyć:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>Repozytoria MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Wybierz dla mnie najszybsze repozytorium MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>szukaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Repozytoria Debian</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Wybierz dla mnie najszybsze repozytorium Debiana</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>Poszczególne źródła</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>Przywróć oryginalne źródła APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Display help </source>
        <translation>Wyświetl pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="386"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Quit application</source>
        <translation>Zakończ aplikację</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <location filename="../mainwindow.cpp" line="557"/>
        <location filename="../mainwindow.cpp" line="937"/>
        <source>Success</source>
        <translation>Sukces </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <location filename="../mainwindow.cpp" line="558"/>
        <location filename="../mainwindow.cpp" line="941"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>Twój nowy wybór zacznie obowiązywać po następnym uaktualnieniu źródeł.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="348"/>
        <source>Lists</source>
        <translation>Listy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="348"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Źródła (zaznaczone źródła są włączone)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <location filename="../mainwindow.cpp" line="784"/>
        <location filename="../mainwindow.cpp" line="805"/>
        <location filename="../mainwindow.cpp" line="815"/>
        <location filename="../mainwindow.cpp" line="823"/>
        <location filename="../mainwindow.cpp" line="838"/>
        <location filename="../mainwindow.cpp" line="851"/>
        <location filename="../mainwindow.cpp" line="858"/>
        <location filename="../mainwindow.cpp" line="874"/>
        <location filename="../mainwindow.cpp" line="881"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>Could not change the repo.</source>
        <translation>Nie można zmienić repozytorium.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>Please wait...</source>
        <translation>Proszę czekać...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="668"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="670"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Program do wybierania domyślnego repozytorium APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="672"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="673"/>
        <source>%1 License</source>
        <translation>%1 Licencja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>%1 Help</source>
        <translation>%1 Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="704"/>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="705"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Wybrałeś testowe repozytorium MX. Nie zaleca się pozostawienia go włączonego do uaktualnienia z niego wszystkich pakietów.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="708"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>Bezpieczniejszą opcją jest pojedyncza instalacja pakietów za pomocą MX Package Installer.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="745"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Wybierz repozytorium APT i źródła, których chcesz użyć:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="805"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt nie może wykryć najszybszego repozytorium.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="784"/>
        <location filename="../mainwindow.cpp" line="815"/>
        <location filename="../mainwindow.cpp" line="823"/>
        <location filename="../mainwindow.cpp" line="838"/>
        <source>Could not detect fastest repo.</source>
        <translation>Nie można wykryć najszybszego repozytorium.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="851"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>Nie mogę ustalić, czy ta aplikacja działa na antiX czy MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="859"/>
        <source>MX version not detected or out of range: </source>
        <translation>Wersja MX nie została wykryta lub jest poza zakresem:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="874"/>
        <source>Could not download original APT files.</source>
        <translation>Nie można pobrać oryginalnych plików APT.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="881"/>
        <source>Could not unzip downloaded file.</source>
        <translation>Nie można rozpakować pobranego pliku.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="924"/>
        <source>Enabling AHS</source>
        <translation>Włączanie AHS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="924"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>Czy korzystasz z repozytorium AHS (Advanced Hardware Stack)?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="938"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>Oryginalne źródła APT zostały przywrócone do stanu z momentu wydania. Pliki ze źródłami dodane przez użytkownika w /etc/apt/sources.list.d/ nie zostały zmienione.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="49"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="50"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Wygląda na to, że jesteś zalogowany jako root, wyloguj się i zaloguj jako zwykły użytkownik, aby korzystać z tego programu.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Musisz uruchomić ten program z uprawnieniami administratora.</translation>
    </message>
</context>
</TS>